[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,147 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDA Experimental in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/barrier>
|
||||
#include <cuda/devices>
|
||||
#include <cuda/hierarchy>
|
||||
#include <cuda/launch>
|
||||
#include <cuda/std/cstddef>
|
||||
#include <cuda/std/type_traits>
|
||||
#include <cuda/stream>
|
||||
|
||||
#include <cuda/experimental/group.cuh>
|
||||
|
||||
#include "group_testing.cuh"
|
||||
|
||||
namespace
|
||||
{
|
||||
template <class Level, class Config>
|
||||
__device__ void test_barrier_synchronizer(const Level& level, Config config)
|
||||
{
|
||||
constexpr cuda::std::size_t nbarriers = 8;
|
||||
|
||||
// Test constructor from static span of barriers.
|
||||
{
|
||||
auto& barriers = get_barriers<nbarriers, 0>(level);
|
||||
using Barrier = cuda::std::remove_all_extents_t<cuda::std::remove_reference_t<decltype(barriers)>>;
|
||||
|
||||
cuda::std::span<Barrier, nbarriers> barriers_span{barriers, nbarriers};
|
||||
cudax::barrier_synchronizer synchronizer{barriers_span};
|
||||
|
||||
static_assert(cuda::std::is_same_v<cudax::barrier_synchronizer<Barrier, nbarriers>, decltype(synchronizer)>);
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<decltype(synchronizer), decltype(barriers_span)>);
|
||||
|
||||
CHECK(synchronizer.barriers().data() == barriers);
|
||||
CHECK(synchronizer.barriers().size() == nbarriers);
|
||||
}
|
||||
|
||||
// Test constructor from dynamic span of barriers.
|
||||
{
|
||||
auto& barriers = get_barriers<nbarriers, 1>(level);
|
||||
using Barrier = cuda::std::remove_all_extents_t<cuda::std::remove_reference_t<decltype(barriers)>>;
|
||||
|
||||
cuda::std::span<Barrier> barriers_span{barriers, nbarriers};
|
||||
cudax::barrier_synchronizer synchronizer{barriers_span};
|
||||
|
||||
static_assert(
|
||||
cuda::std::is_same_v<cudax::barrier_synchronizer<Barrier, cuda::std::dynamic_extent>, decltype(synchronizer)>);
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<decltype(synchronizer), decltype(barriers_span)>);
|
||||
|
||||
CHECK(synchronizer.barriers().data() == barriers);
|
||||
CHECK(synchronizer.barriers().size() == nbarriers);
|
||||
}
|
||||
|
||||
// Test constructor from array of barriers.
|
||||
{
|
||||
auto& barriers = get_barriers<nbarriers, 2>(level);
|
||||
using Barrier = cuda::std::remove_all_extents_t<cuda::std::remove_reference_t<decltype(barriers)>>;
|
||||
|
||||
cudax::barrier_synchronizer synchronizer{barriers};
|
||||
|
||||
static_assert(cuda::std::is_same_v<cudax::barrier_synchronizer<Barrier, nbarriers>, decltype(synchronizer)>);
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<decltype(synchronizer), decltype(barriers)>);
|
||||
|
||||
CHECK(synchronizer.barriers().data() == barriers);
|
||||
CHECK(synchronizer.barriers().size() == nbarriers);
|
||||
}
|
||||
|
||||
// Test barriers().
|
||||
{
|
||||
auto& barriers = get_barriers<nbarriers, 3>(level);
|
||||
using Barrier = cuda::std::remove_all_extents_t<cuda::std::remove_reference_t<decltype(barriers)>>;
|
||||
|
||||
const cudax::barrier_synchronizer synchronizer{barriers};
|
||||
|
||||
static_assert(cuda::std::is_same_v<cuda::std::span<Barrier, nbarriers>, decltype(synchronizer.barriers())>);
|
||||
static_assert(noexcept(synchronizer.barriers()));
|
||||
|
||||
CHECK(synchronizer.barriers().data() == barriers);
|
||||
CHECK(synchronizer.barriers().size() == nbarriers);
|
||||
}
|
||||
|
||||
// Test make_instance(...).
|
||||
{
|
||||
auto& barriers = get_barriers<nbarriers, 4>(level);
|
||||
using Barrier = cuda::std::remove_all_extents_t<cuda::std::remove_reference_t<decltype(barriers)>>;
|
||||
|
||||
const auto parent_group = cudax::make_this_group(level, config);
|
||||
const ThreadsInWarpMappingResult prev_mapping_result;
|
||||
|
||||
const cudax::group_by mapping{4};
|
||||
const cudax::barrier_synchronizer synchronizer{barriers};
|
||||
|
||||
const auto mapping_result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
|
||||
const auto synchronizer_instance =
|
||||
synchronizer.make_instance(cuda::gpu_thread, parent_group, mapping, mapping_result);
|
||||
|
||||
// Test do_sync(...).
|
||||
static_assert(cuda::std::is_same_v<void, decltype(synchronizer_instance.do_sync(mapping_result, synchronizer))>);
|
||||
static_assert(noexcept(synchronizer_instance.do_sync(mapping_result, synchronizer)));
|
||||
synchronizer_instance.do_sync(mapping_result, synchronizer);
|
||||
|
||||
// Test do_sync_aligned(...).
|
||||
static_assert(
|
||||
cuda::std::is_same_v<void, decltype(synchronizer_instance.do_sync_aligned(mapping_result, synchronizer))>);
|
||||
static_assert(noexcept(synchronizer_instance.do_sync_aligned(mapping_result, synchronizer)));
|
||||
synchronizer_instance.do_sync_aligned(mapping_result, synchronizer);
|
||||
}
|
||||
}
|
||||
|
||||
struct TestKernel
|
||||
{
|
||||
template <class Config>
|
||||
__device__ void operator()(const Config& config)
|
||||
{
|
||||
test_barrier_synchronizer(cuda::warp, config);
|
||||
test_barrier_synchronizer(cuda::block, config);
|
||||
test_barrier_synchronizer(cuda::cluster, config);
|
||||
test_barrier_synchronizer(cuda::grid, config);
|
||||
}
|
||||
};
|
||||
} // namespace
|
||||
|
||||
C2H_TEST("Barrier synchronizer", "[group]")
|
||||
{
|
||||
const auto device = cuda::devices[0];
|
||||
|
||||
const cuda::stream stream{device};
|
||||
|
||||
{
|
||||
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<8, 4>(), cuda::cooperative_launch{});
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
{
|
||||
const auto config =
|
||||
cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims(dim3{8, 4}), cuda::cooperative_launch{});
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
|
||||
stream.sync();
|
||||
}
|
||||
@@ -1,87 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDA Experimental in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/devices>
|
||||
#include <cuda/hierarchy>
|
||||
#include <cuda/launch>
|
||||
#include <cuda/std/bit>
|
||||
#include <cuda/std/type_traits>
|
||||
#include <cuda/stream>
|
||||
|
||||
#include <cuda/experimental/group.cuh>
|
||||
|
||||
#include "group_testing.cuh"
|
||||
|
||||
namespace
|
||||
{
|
||||
template <class Level, class Config>
|
||||
__device__ void test_lane_synchronizer(const Level& level, Config config)
|
||||
{
|
||||
using Synchronizer = cudax::lane_synchronizer;
|
||||
static_assert(cuda::std::is_empty_v<Synchronizer>);
|
||||
|
||||
// Test default constructor.
|
||||
static_assert(cuda::std::is_trivially_default_constructible_v<Synchronizer>);
|
||||
|
||||
// Test make_instance(...).
|
||||
{
|
||||
const auto parent_group = cudax::make_this_group(level, config);
|
||||
const ThreadsInWarpMappingResult prev_mapping_result;
|
||||
|
||||
const cudax::group_by mapping{2};
|
||||
const Synchronizer synchronizer{};
|
||||
|
||||
const auto mapping_result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
|
||||
const auto synchronizer_instance =
|
||||
synchronizer.make_instance(cuda::gpu_thread, parent_group, mapping, mapping_result);
|
||||
|
||||
// Test do_sync(...).
|
||||
static_assert(cuda::std::is_same_v<void, decltype(synchronizer_instance.do_sync(mapping_result, synchronizer))>);
|
||||
static_assert(noexcept(synchronizer_instance.do_sync(mapping_result, synchronizer)));
|
||||
synchronizer_instance.do_sync(mapping_result, synchronizer);
|
||||
|
||||
// Test do_sync_aligned(...).
|
||||
static_assert(
|
||||
cuda::std::is_same_v<void, decltype(synchronizer_instance.do_sync_aligned(mapping_result, synchronizer))>);
|
||||
static_assert(noexcept(synchronizer_instance.do_sync_aligned(mapping_result, synchronizer)));
|
||||
synchronizer_instance.do_sync_aligned(mapping_result, synchronizer);
|
||||
}
|
||||
}
|
||||
|
||||
struct TestKernel
|
||||
{
|
||||
template <class Config>
|
||||
__device__ void operator()(const Config& config)
|
||||
{
|
||||
test_lane_synchronizer(cuda::warp, config);
|
||||
test_lane_synchronizer(cuda::block, config);
|
||||
test_lane_synchronizer(cuda::cluster, config);
|
||||
test_lane_synchronizer(cuda::grid, config);
|
||||
}
|
||||
};
|
||||
} // namespace
|
||||
|
||||
C2H_TEST("Lane synchronizer", "[group]")
|
||||
{
|
||||
const auto device = cuda::devices[0];
|
||||
|
||||
const cuda::stream stream{device};
|
||||
|
||||
{
|
||||
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<8, 4>());
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
{
|
||||
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims(dim3{8, 4}));
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
|
||||
stream.sync();
|
||||
}
|
||||
Reference in New Issue
Block a user